﻿// Copyright (c) 2020 Tudor Stanciu

using System;
using System.Collections.Generic;
using System.Linq;
using Tuitio.Domain.Entities;
using Tuitio.Domain.Models;

namespace Tuitio.Application.Extensions
{
    internal static class EntityConversions
    {
        public static Dictionary<string, string> ToDictionary(this ICollection<UserClaim> claims)
        {
            if (claims == null)
                return null;

            var result = new Dictionary<string, string>();
            foreach (var claim in claims)
                result.Add(claim.ClaimKey, claim.ClaimValue);

            return result;
        }

        public static IEnumerable<RecordIdentifier> AsRecordIdentifiers(this IEnumerable<UserGroup> userGroups)
        {
            if (userGroups == null)
                throw new ArgumentNullException(nameof(userGroups));

            var result = userGroups.Select(z => new RecordIdentifier(z.UserGroupId, z.UserGroupCode));
            return result;
        }

        public static IEnumerable<RecordIdentifier> AsRecordIdentifiers(this IEnumerable<UserRole> userRoles)
        {
            if (userRoles == null)
                throw new ArgumentNullException(nameof(userRoles));

            var result = userRoles.Select(z => new RecordIdentifier(z.UserRoleId, z.UserRoleCode));
            return result;
        }
    }
}
