﻿// Copyright (c) 2020 Tudor Stanciu

using MediatR;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using System.Threading.Tasks;
using Tuitio.Application.CommandHandlers;
using Tuitio.Application.Queries;

namespace Tuitio.Api.Controllers
{
    [Authorize]
    [ApiController]
    [Route("connect")]
    public class ConnectController : ControllerBase
    {
        private readonly IMediator _mediator;

        public ConnectController(IMediator mediator)
        {
            _mediator = mediator;
        }

        [AllowAnonymous]
        [HttpPost("authorize")]
        public async Task<IActionResult> AuthorizeToken([FromQuery] string token)
        {
            var command = new AuthorizationHandler.Command(token);
            var result = await _mediator.Send(command);
            return Ok(result);
        }

        [HttpGet("user-info")]
        public async Task<IActionResult> GetUserInfo()
        {
            var command = new GetUserInfo.Query();
            var result = await _mediator.Send(command);
            return Ok(result);
        }
    }
}
